@@ -1,3 +1,17 @@
+# Copyright 2023 The Pgx Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from functools import partial
 
 import jax
@@ -62,6 +76,10 @@ class Backgammon(pgx.Env):
         assert isinstance(state, State)
         return observe(state, player_id)
 
+    @property
+    def name(self) -> str:
+        return "Backgammon"
+
     @property
     def version(self) -> str:
         return "beta"
