@@ -1,3 +1,17 @@
+# Copyright 2023 The Pgx Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import abc
 from typing import Literal, Tuple, get_args
 
@@ -148,6 +162,11 @@ class Env(abc.ABC):
         """Implement game-specific observe function here."""
         ...
 
+    @property
+    @abc.abstractmethod
+    def name(self) -> str:
+        ...
+
     @property
     @abc.abstractmethod
     def version(self) -> str:
