@@ -1,3 +1,17 @@
+# Copyright 2023 The Pgx Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from functools import partial
 
 import jax
@@ -45,11 +59,12 @@ class Go(pgx.Env):
         max_truncation_steps: int = -1,
         size: int = 19,
         komi: float = 7.5,
-        history_length: int = 8
+        history_length: int = 8,
     ):
         super().__init__(
             auto_reset=auto_reset, max_truncation_steps=max_truncation_steps
         )
+        assert isinstance(size, int)
         self.size = size
         self.komi = komi
         self.history_length = history_length
@@ -81,6 +96,10 @@ class Go(pgx.Env):
             observe, size=self.size, history_length=self.history_length
         )(state=state, player_id=player_id)
 
+    @property
+    def name(self) -> str:
+        return f"Go ({int(self.size)}x{int(self.size)})"
+
     @property
     def version(self) -> str:
         return "beta"
