@@ -1,3 +1,17 @@
+# Copyright 2023 The Pgx Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import math
 from dataclasses import dataclass
 from typing import Literal
@@ -146,7 +160,7 @@ class Visualizer:
         states,
     ):
         try:
-            SIZE = len(states.turn)
+            SIZE = len(states.current_player)
             WIDTH = math.ceil(math.sqrt(SIZE - 0.1))
             if SIZE - (WIDTH - 1) ** 2 >= WIDTH:
                 HEIGHT = WIDTH
@@ -556,7 +570,7 @@ class Visualizer:
         elif isinstance(_states, GoState):
             return GoState(  # type:ignore
                 size=_states.size[_i],
-                ren_id_board=_states.chain_id_board[_i],
+                chain_id_board=_states.chain_id_board[_i],
                 turn=_states.turn[_i],
             )
         elif isinstance(_states, OthelloState):
